#
# spec file for package python-pytest-rerunfailures
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-rerunfailures
Version:        15.0
Release:        1.2
Summary:        A pytest plugin to re-run tests
License:        MPL-2.0
URL:            https://github.com/pytest-dev/pytest-rerunfailures
Source:         https://files.pythonhosted.org/packages/source/p/pytest-rerunfailures/pytest-rerunfailures-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 40.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-packaging >= 17.1
Requires:       python-pytest >= 7.4
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 7.4}
BuildRequires:  %{python_module pytest-xdist}
# /SECTION
%python_subpackages

%description
The pytest-rerunfailures package is a plugin for Pytest that re-runs
tests to eliminate intermittent failures.

%prep
%setup -q -n pytest-rerunfailures-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# https://github.com/pytest-dev/pytest-rerunfailures/issues/267
donttest="test_run_session_teardown_once_after_reruns "
donttest+="or test_exception_matches_rerun_except_query "
donttest+="or test_exception_not_match_rerun_except_query "
donttest+="or test_exception_matches_only_rerun_query "
donttest+="or test_exception_match_only_rerun_in_dual_query"
%pytest -k "not (${donttest})"

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE
%{python_sitelib}/pytest_rerunfailures.py
%pycache_only %{python_sitelib}/__pycache__/pytest_rerunfailures*pyc
%{python_sitelib}/pytest_rerunfailures-%{version}.dist-info

%changelog
* Mon Nov 25 2024 Dirk Müller <dmueller@suse.com>
- update to 15.0:
  * Drop support for Python 3.8.
  * Drop support for pytest < 7.4.
  * Fix compatibility with pytest 8.2.
  * Add support for pytest 8.2, 8.3.
  * Add --fail-on-flaky option to fail the test run with custom
    exit code when test passed on rerun.
* Tue May  7 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- Skip some tests that have been broken by pytest 8.2.
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 14.0:
  * Fix missing teardown for non-function scoped fixtures when
    using only_rerun or rerun_except queries. (#234) and
  * Drop support for Python 3.7.
  * Drop support for pytest < 7.2.
  * Add support for pytest 8.0, 8.1.
* Thu Dec 14 2023 Dirk Müller <dmueller@suse.com>
- update to 13.0:
  * Drop support for pytest < 7.0.
  * Add support for Python 3.12.
  * Fix crashitem names mismatch between client and server.
  * Fix crash when setup fails with --rerun-except flag.
* Mon Jul 24 2023 Dirk Müller <dmueller@suse.com>
- update to 12.0:
  * Drop support for pytest < 6.2.
  * Add ``only_rerun`` and ``rerun_except`` arguments to
    ``@pytest.mark.flaky`` marker.
  * Add support for pytest 7.3, 7.4.
  * Failures are now rerun only if they match at least one
    ``--only-rerun`` pattern (if given) and none of the
    ``--rerun-except`` patterns. Previously, using both
    ``--only-rerun`` and ``--rerun-except`` together
    could cause failures to be rerun even if they did not
    match any ``--only-rerun`` pattern, and when using
    multiple ``--rerun-except`` patterns, all failures
    would be rerun unless they matched every pattern.
* Tue May  9 2023 Dirk Müller <dmueller@suse.com>
- update to 11.1.2:
  * Execute teardown when test was skipped in setup phase of a
    fixture.
  * Fix crash during teardown when runtest protocol hook is
    overwritten by another plugin.
  * Fix crash during teardown when TestCase class is used as base
    class.
  * Run teardown of session, class, ... scoped fixtures only once
    after rerunning tests
  * Expose `reruns` and `reruns_delay` through `pytest.ini` file.
  * Drop support for Python 3.6.
  * Drop support for pytest < 6.
  * Fix crash when pytest-xdist is installed but disabled.
  * Fix crash when xfail(strict=True) mark is used with --rerun-
    only flag.
  * Added option `--rerun-except` to rerun failed tests those are
    other than the mentioned Error.
  * Add support for Python 3.11.
  * Add support for pytest 7.0, 7.1, 7.2.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Mar 28 2022 Ben Greiner <code@bnavigator.de>
- Update to 10.2
  * Allow recovery from crashed tests with pytest-xdist.
  * Add support for Python 3.10 (as of Python 3.10.rc2). (Thanks to
    @hugovk for the PR.)
  * Allows using a str as condition for
    @pytest.mark.flaky(condition) which gets evaluated dynamically
    similarly to @pytest.mark.skipif(condition). (#162 provided by
    @15klli)
  * Drop support for Python 3.5.
  * Drop support for pytest < 5.3.
  * Add condition keyword argument to the re-run marker. (Thanks to
    @BeyondEvil for the PR.)
  * Add support for Python 3.9. (Thanks to @digitronik for the PR.)
  * Add support for pytest 6.3. (Thanks to @bluetech for the PR.)
  * Add compatibility with pytest-xdist >= 2.0. (Thanks to
    @bluetech for the PR.)
  * Check for the resultlog by feature and not by version as pytest
    master does not provide a consistent version.
* Sat Nov  7 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 9.1.1
  Compatibility fix.
  * Ignore --result-log command line option when used together with
    pytest >= 6.1.0, as it was removed there. This is a quick fix,
    use an older version of pytest, if you want to keep this
    feature for now. (Thanks to @ntessore for the PR)
  * Support up to pytest 6.1.0.
- Changelog for 9.1
  Features
  * Add a new flag --only-rerun to allow for users to rerun only
    certain errors.
  Other changes
  * Drop dependency on mock.
  * Add support for pre-commit and add a linting tox target. (#117)
    (PR from @gnikonorov)
* Mon Mar 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 9.0:
  * Add support for pytest 5.4.
  * Add support for Python 3.8.
  * Drop support for python 2.7
* Wed Dec  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 8.0:
  * Explicitly depend on setuptools to ensure installation when
    working in environments without it
* Thu Mar 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 7.0:
  * Drop support for pytest version 3.8 and 3.9.
  * Add support for pytest version 4.2 and 4.3.
  * Fixed #83 issue about ignored pytest_runtest_logfinish hooks
* Fri Feb 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Enable tests really
- Update to 6.0:
  * Drop support for pytest version 3.6 and 3.7.
  * Add support for pytest version 4.0 and 4.1.
  * Fixed #77 regression issue introduced in 4.2 related to the rerun attribute on the test report. (#77) (Thanks to @RibeiroAna for the PR).
* Thu Nov 15 2018 Todd R <toddrme2178@gmail.com>
- Initial version
